@@ -1,25 +1,25 @@
-from getopt import GetoptError
+from getopt import GetoptError, getopt
 import sys
+import os
 import logging
 
 logger = logging.getLogger(__name__)
 
 
-def main(args=None):
-    if args is None:
-        args = sys.argv[1:]
+def main():
+    args = sys.argv[1:]
 
     try:
-        opts, args = parse_command(args)
+        opts, args = getopt(args, 'hc', ['help', 'create_master_salt'])
     except GetoptError as exc:
         sys.stderr.write("ERROR: %s" % exc)
         sys.stderr.write(os.linesep)
-        return 1
+        sys.exit(1)
 
     for cmd, arg in opts:
-        if cmd == '-h':
-            print('KGlobal -create_master_salt')
-        elif cmd == '-create_master_salt':
+        if cmd == '--help' or cmd == '-h':
+            print('KGlobal [-c, --create_master_salt]')
+        elif cmd == '--create_master_salt' or cmd == '-c':
             try:
                 print('Creating Master Salt Key....')
                 from . import create_master_salt_key
@@ -28,6 +28,4 @@ def main(args=None):
             except Exception as exc:
                 sys.stderr.write("ERROR: %s" % exc)
                 sys.stderr.write(os.linesep)
-                return 1
-
-    return 0
+                sys.exit(1)
