@@ -213,14 +213,23 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                 params = dict(query_str=query_str, execute=execute)
                 cursor = SQLCursor(engine_type=self.engine_type, engine=engine, engine_class=self, action="execute",
                                    action_params=params)
-                self.__cursors.put(cursor, block=False)
-                cursor.start()
+
+                try:
+                    self.__cursors.put(cursor, block=False)
+                    cursor.start()
+                except:
+                    cursor.close()
             else:
                 cursor = SQLCursor(engine_type=self.engine_type, engine=engine)
-                cursor.start()
-                cursor.execute(query_str, execute)
-                cursor.join()
-                return cursor
+
+                try:
+                    cursor.start()
+                    cursor.execute(query_str, execute)
+                    cursor.join()
+                except:
+                    cursor.close()
+                else:
+                    return cursor
 
     def sql_upload(self, dataframe, table_name, table_schema=None, if_exists='append', index=True, index_label='ID',
                    queue_cursor=False):
@@ -248,14 +257,23 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                                   if_exists=if_exists, index=index, index_label=index_label)
                     cursor = EngineCursor(alch_engine=engine, engine_class=self, action='upload_df',
                                           action_params=params)
-                    self.__cursors.put(cursor, block=False)
-                    cursor.start()
+
+                    try:
+                        self.__cursors.put(cursor, block=False)
+                        cursor.start()
+                    except:
+                        cursor.close()
                 else:
                     cursor = EngineCursor(alch_engine=engine)
-                    cursor.start()
-                    cursor.upload_df(dataframe, table_name, table_schema, if_exists, index, index_label)
-                    cursor.join()
-                    return cursor
+
+                    try:
+                        cursor.start()
+                        cursor.upload_df(dataframe, table_name, table_schema, if_exists, index, index_label)
+                        cursor.join()
+                    except:
+                        cursor.close()
+                    else:
+                        return cursor
 
     def sql_tables(self, queue_cursor=False):
         """
@@ -268,18 +286,24 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         from ..sql.cursor import SQLCursor
 
         with self.__engine_lock:
-            cursor = SQLCursor(engine_type=self.engine_type, engine=self.connect())
+            engine = self.connect()
+            cursor = SQLCursor(engine_type=self.engine_type, engine=engine)
 
-            if queue_cursor:
-                cursor.start()
-                cursor.engine_class = self
-                self.__cursors.put(cursor, block=False)
-                cursor.tables()
+            try:
+                if queue_cursor:
+                    cursor.start()
+                    cursor.engine_class = self
+                    self.__cursors.put(cursor, block=False)
+                    cursor.tables()
+                else:
+                    cursor.start()
+                    cursor.tables()
+                    cursor.join()
+            except:
+                cursor.close()
             else:
-                cursor.start()
-                cursor.tables()
-                cursor.join()
-                return cursor
+                if not queue_cursor and cursor:
+                    return cursor
 
     def wait_for_cursors(self, timeout=0):
         """
@@ -297,14 +321,17 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                 curr_time = datetime.now()
                 end_time = datetime.now() + timedelta(seconds=timeout)
 
-                while (curr_time < end_time or timeout == 0) and len(self.cursors) > 0:
-                    curr_time = datetime.now()
-                    sleep(1)
+                try:
+                    while (curr_time < end_time or timeout == 0) and len(self.cursors) > 0:
+                        curr_time = datetime.now()
+                        sleep(1)
 
-                if len(self.cursors) > 0:
-                    raise ValueError("Not all cursors are complete. Operation timed out")
-                else:
-                    return self.__cursor_results
+                    if len(self.cursors) > 0:
+                        raise ValueError("Not all cursors are complete. Operation timed out")
+                    else:
+                        return self.__cursor_results
+                except:
+                    self.__release_coms()
         else:
             return self.__cursor_results
 
