@@ -18,7 +18,7 @@ class Toolbox(SQLQueue, LogHandle):
     __main_config = None
     __pointer = None
 
-    def __init__(self, script_path, logging_path=None, max_pool_size=SQL_POOLSIZE):
+    def __init__(self, script_path, logging_path=None, logging_base_name=None, max_pool_size=SQL_POOLSIZE):
         """
         Lets setup SQLQueue, Logging, Main Config, and Local Config
 
@@ -27,9 +27,13 @@ class Toolbox(SQLQueue, LogHandle):
         :param max_pool_size: (Optional) SQL max poolsize for connection queue
         """
 
-        if logging_path and os.path.exists(logging_path):
-            file_dir = os.path.dirname(logging_path)
-            base_name = os.path.basename(logging_path)
+        if logging_path and os.path.exists(logging_path) and os.path.isdir(logging_path):
+            file_dir = logging_path
+
+            if logging_base_name:
+                base_name = os.path.basename(logging_base_name)
+            else:
+                base_name = os.path.basename(script_path)
         else:
             file_dir = None
             base_name = None
